@@ -489,7 +489,7 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        if form.instance._state.adding == False:
+        if hasattr(form.instance,'get_children'):
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
                                                                  fk_name='parent',
                                                                  extra=1, form=DataTransform
